import { Address, AliasAddress } from '../address';
/**
 * All of the unlock condition types.
 */
declare enum UnlockConditionType {
    Address = 0,
    StorageDepositReturn = 1,
    Timelock = 2,
    Expiration = 3,
    StateControllerAddress = 4,
    GovernorAddress = 5,
    ImmutableAliasAddress = 6
}
declare abstract class UnlockCondition {
    readonly type: UnlockConditionType;
    constructor(type: UnlockConditionType);
    /**
     * The type of unlock condition.
     */
    getType(): UnlockConditionType;
    static parse(data: any): UnlockCondition;
}
declare class AddressUnlockCondition extends UnlockCondition {
    readonly address: Address;
    constructor(address: Address);
    /**
     * The address.
     */
    getAddress(): Address;
}
/**
 * Storage Deposit Return Unlock Condition.
 */
declare class StorageDepositReturnUnlockCondition extends UnlockCondition {
    readonly amount: string;
    readonly returnAddress: Address;
    constructor(returnAddress: Address, amount: bigint | string);
    /**
     * Amount of tokens the consuming transaction must deposit to the address defined in return address.
     */
    getAmount(): bigint;
    /**
     * The return address.
     */
    getReturnAddress(): Address;
}
/**
 * Timelock Unlock Condition.
 */
declare class TimelockUnlockCondition extends UnlockCondition {
    readonly unixTime: number;
    constructor(unixTime: number);
    /**
     * Unix time (seconds since Unix epoch) starting from which the output can be consumed.
     */
    getUnixTime(): number;
}
declare class ExpirationUnlockCondition extends UnlockCondition {
    readonly returnAddress: Address;
    readonly unixTime: number;
    constructor(returnAddress: Address, unixTime: number);
    /**
     * Before this unix time, the condition is allowed to unlock the output,
     * after that only the address defined in return address.
     */
    getUnixTime(): number;
    /**
     * The return address.
     */
    getReturnAddress(): Address;
}
/**
 * State Controller Address Unlock Condition.
 */
declare class StateControllerAddressUnlockCondition extends UnlockCondition {
    readonly address: Address;
    constructor(address: Address);
    /**
     * The address.
     */
    getAddress(): Address;
}
/**
 * Governor Unlock Condition.
 */
declare class GovernorAddressUnlockCondition extends UnlockCondition {
    readonly address: Address;
    constructor(address: Address);
    /**
     * The address.
     */
    getAddress(): Address;
}
/**
 * Immutable Alias Unlock Condition.
 */
declare class ImmutableAliasAddressUnlockCondition extends UnlockCondition {
    readonly address: Address;
    constructor(address: AliasAddress);
    /**
     * The address.
     */
    getAddress(): Address;
}
declare const UnlockConditionDiscriminator: {
    property: string;
    subTypes: ({
        value: typeof AddressUnlockCondition;
        name: any;
    } | {
        value: typeof StorageDepositReturnUnlockCondition;
        name: any;
    } | {
        value: typeof TimelockUnlockCondition;
        name: any;
    } | {
        value: typeof ExpirationUnlockCondition;
        name: any;
    })[];
};
export { UnlockConditionDiscriminator, UnlockCondition, UnlockConditionType, AddressUnlockCondition, StorageDepositReturnUnlockCondition, TimelockUnlockCondition, ExpirationUnlockCondition, StateControllerAddressUnlockCondition, GovernorAddressUnlockCondition, ImmutableAliasAddressUnlockCondition, };
